'use client'

import { useEffect, useState } from 'react'
import { Input } from '@/components/ui/input'
import { Spinner } from '@/components/ui/spinner'

interface bsetJsonObject {
  name:               string,
  sanitized_name:     string,
  set_codes:          string[],
  icons:              string[]
}


export default function Home() {
  const [displayedBsetList, setDisplayedBsetList] = useState([])
  const [originalBsetList, setOriginalBsetList] = useState([])
  const [loading, setLoading] = useState(true)

  useEffect(() => {
    fetch('/api/json/misc/bsets.json').then((res) => {
      if(res.status == 200) {
        res.json().then((data) => {
          setLoading(false)
          setOriginalBsetList(data)
          setDisplayedBsetList(data)
        })
      }
    })
  }, []) 

  function filterBsetList(searchString:string) {
    if(searchString != "") {
      setDisplayedBsetList(originalBsetList.filter((bset:bsetJsonObject) => bset.name.toLowerCase().includes(searchString.toLowerCase())))
    } else {
      setDisplayedBsetList(originalBsetList)
    }
  }

  return (
    <div className="flex flex-col items-center mt-16">
      <div className="flex flex-col p-16 max-w-6xl w-full gap-4 items-center">
        <Input placeholder="Rechercher des BrawlSets..." onChange={(e) => filterBsetList(e.target.value)}/>
        { loading && <Spinner className='mt-24'/> }
        { !loading && (
          <div className="grid grid-cols-3 gap-4 p-2 w-full">
            { displayedBsetList.map((bset: bsetJsonObject) => (
              <a key={bset.name} className="flex flex-row gap-2 items-center text-stone-500" href={"/bset/" + bset.sanitized_name}>
                <div className="flex flex-row gap-1">
                  { bset.icons.map((icon) => (
                    <img key={icon} src={icon} loading="lazy" className="w-5 h-5"/>
                  ))}
                </div>
                <span>{bset.name}</span>
              </a>
            ))}
          </div>
        )}
      </div>
    </div>
  );
}
